<?php

namespace Kaizen_Coders\Url_Shortify\Admin;

use Kaizen_Coders\Url_Shortify\Admin\DB\Clicks;
use Kaizen_Coders\Url_Shortify\Common\Browser;
use Kaizen_Coders\Url_Shortify\Common\Ip2Geo;
use Kaizen_Coders\Url_Shortify\Helper;

/**
 * Class Click
 *
 * @package Kaizen_Coders\Url_Shortify\Admin
 *
 * @since 1.0.2
 */
class Click {

	/**
	 * @var array|int
	 *
	 * @since 1.0.2
	 */
	public $link_id = 0;

	/**
	 * @var Clicks|null
	 *
	 * @since 1.0.2
	 */
	public $db = null;

	/**
	 * @var string
	 *
	 * @since 1.0.2
	 */
	public $slug = null;

	/**
	 * @var string|null
	 *
	 * @since 1.0.2
	 */
	public $uri = null;

	/**
	 * @var null
	 *
	 * @since 1.0.2
	 */
	public $host = null;

	/**
	 * @var null
	 *
	 * @since 1.0.2
	 */
	public $referer = null;

	/**
	 * @var int
	 *
	 * @since 1.0.2
	 */
	public $is_first_click = 0;

	/**
	 * @var int
	 *
	 * @since 1.0.2
	 */
	public $is_robot = 0;

	/**
	 * @var null
	 *
	 * @since 1.0.2
	 */
	public $user_agent = null;

	/**
	 * @var null
	 *
	 * @since 1.0.2
	 */
	public $os = null;

	/**
	 * @var null
	 *
	 * @since 1.0.2
	 */
	public $device = null;

	/**
	 * @var null
	 *
	 * @since 1.0.2
	 */
	public $browser_type = null;

	/**
	 * @var null
	 *
	 * @since 1.0.2
	 */
	public $browser_version = null;

	/**
	 * @var null
	 *
	 * @since 1.0.2
	 */
	public $visitor_id = null;

	/**
	 * @var null
	 *
	 * @since 1.0.2
	 */
	public $country = null;

	/**
	 * @var null
	 *
	 * @since 1.0.2
	 */
	public $ip = null;

	/**
	 * @var null
	 *
	 * @since 1.0.2
	 */
	public $created_at = null;

	/**
	 * Click constructor.
	 *
	 * @param null $link_id
	 * @param null $slug
	 *
	 * @since 1.0.2
	 */
	public function __construct( $link_id = null, $slug = null ) {

		$this->link_id = $link_id;
		$this->slug    = $slug;
		$this->db      = new Clicks();
	}

	/**
	 * Track link clicks
	 *
	 * @since 1.0.2
	 */
	public function track() {

		$browser = new Browser();

		$this->is_first_click = 0;

		$this->ip = Helper::get_ip();

		try {
			$ip2geo  = new Ip2Geo( $this->ip );
			$country = $ip2geo->get_country_iso_code();
		} catch ( \Exception $e ) {
			$country = null;
		}

		$this->country = $country;

		$this->referer = Helper::get_data( $_SERVER, 'HTTP_REFERER', '', true );
		$this->uri     = Helper::get_data( $_SERVER, 'REQUEST_URI', '', true );

		$this->user_agent = $browser->getUserAgent();

		$cookie_name = 'kc_us_click_' . $this->link_id;

		$cookie_expire_time = time() + 60 * 60 * 24 * 30; // Expire in 30 days

		if ( ! isset( $_COOKIE[ $cookie_name ] ) ) {
			setcookie( $cookie_name, $this->slug, $cookie_expire_time, '/' );
			$this->is_first_click = 1;
		}

		$visitor_cookie             = 'kc_us_visitor';
		$visitor_cookie_expire_time = time() + 60 * 60 * 24 * 365; // Expire in 1 year

		if ( ! isset( $_COOKIE[ $visitor_cookie ] ) ) {
			$this->visitor_id = $this->generate_unique_visitor_id();
			setcookie( $visitor_cookie, $this->visitor_id, $visitor_cookie_expire_time, '/' );
		} else {
			$this->visitor_id = $_COOKIE[ $visitor_cookie ];
		}

		$this->browser_type    = $browser->getBrowser();
		$this->browser_version = $browser->getVersion();
		$this->host            = gethostbyaddr( $this->ip );

		$this->is_robot = $browser->isRobot();
		$this->os       = $browser->getPlatform();

		$device = 'Desktop';
		if ( $browser->isMobile() ) {
			$device = 'Mobile';
		} elseif ( $browser->isTablet() ) {
			$device = 'Tablet';
		}

		$this->device = $device;

		$this->created_at = Helper::get_current_date_time();

		// Saving
		$this->save();
	}

	/**
	 * Generate unique id
	 *
	 * @return string
	 *
	 * @since 1.0.2
	 */
	public function generate_unique_visitor_id() {
		return uniqid();
	}

	/**
	 * Save tracking data
	 *
	 * @since 1.0.2
	 */
	public function save() {

		$defaults_data = $this->db->get_column_defaults();

		$data = array();
		foreach ( $defaults_data as $column => $value ) {
			if ( property_exists( $this, $column ) ) {
				$data[ $column ] = $this->$column;
			} else {
				$data[ $column ] = $value;
			}
		}

		$this->db->save( $data );
	}

}
