<?php

use Kaizen_Coders\Url_Shortify\Admin\Controllers\ClicksController;
use Kaizen_Coders\Url_Shortify\Common\Utils;
use Kaizen_Coders\Url_Shortify\Helper;

$page_refresh_url = Utils::get_current_page_refresh_url();

$short_link = Helper::get_data( $data, 'short_url', '' );

$link_id = Helper::get_data( $data, 'id', '' );

$clicks_data = $data['reports']['clicks'];

$click_data_for_graph = $data['click_data_for_graph'];

$last_updated_on = Helper::get_data( $data, 'last_updated_on', time() );

$elapsed_time = Utils::get_elapsed_time( $last_updated_on );

$labels = $values = '';

$total_clicks = 0;
if ( ! empty( $click_data_for_graph ) ) {

	$labels = json_encode( array_keys( $click_data_for_graph ) );

	$clicks = array_values( $click_data_for_graph );

	$total_clicks = array_sum( $clicks );

	$values = json_encode( $clicks );

}

$columns = array(
	'ip'         => array( 'title' => __( 'IP', 'url-shortify' ) ),
	'host'       => array( 'title' => __( 'Host', 'url-shortify' ) ),
	'referrer'   => array( 'title' => __( 'Referrer', 'url-shortify' ) ),
	'clicked_on' => array( 'title' => __( 'Clicked On', 'url-shortify' ) ),
	'info'       => array( 'title' => __( 'Info', 'url-shortify' ) ),
);

$click_history = new ClicksController();
$click_history->set_columns( $columns );

$quick_links = array(

	array(
		'title'    => __( 'Facebook', 'url-shortify' ),
		'url'      => "https://www.facebook.com/sharer/sharer.php?u=$short_link",
		'icon_url' => KC_US_PLUGIN_ASSETS_DIR_URL . '/images/share/facebook.svg'
	),

	array(
		'title'    => __( 'Twitter', 'url-shortify' ),
		'url'      => "https://twitter.com/intent/tweet?text=Check%20out%20this%20link%20-%20$short_link",
		'icon_url' => KC_US_PLUGIN_ASSETS_DIR_URL . '/images/share/twitter.svg'
	),

	array(
		'title'    => __( 'WhatsApp', 'url-shortify' ),
		'url'      => "https://wa.me?text=Check%20out%20this%20link%20-%20$short_link",
		'icon_url' => KC_US_PLUGIN_ASSETS_DIR_URL . '/images/share/whatsapp.svg'
	),

);

$quick_links = apply_filters( 'kc_us_link_quick_links', $quick_links, $link_id );

?>

<div class="wrap">
    <div class="font-sans bg-grey-lighter flex flex-col min-h-screen w-full">
        <div class="w-full">
            <div class="md:block mt-3 border-b border-gray-300 pb-5">
                <div class="container mx-auto">
                    <div class="md:flex">
                        <div class="flex inline -mb-px mr-8 w-10/12">
								<span class="flex">
									<img class="h-6 w-6 mr-2" src="<?php echo $data['icon_url']; ?>" title="<?php echo $data['url']; ?>"/>
									<strong class="text-2xl">
										<a href="<?php echo $data['url']; ?>" target="_blank">
										 <?php echo stripslashes( $data['name'] ); ?>
										</a>
									</strong>
								</span>
							<?php
							$link = Helper::get_short_link( $data['slug'] );

							echo Helper::create_copy_short_link_html( $link, $data['id'] );
							?>
                        </div>
						<?php if ( Helper::is_forechable( $quick_links ) ) { ?>
                            <div class="flex float-right w-2/12">
								<?php foreach ( $quick_links as $quick_link ) { ?>
                                    <a href="<?php echo esc_url( $quick_link['url'] ); ?>" target="_blank" title="<?php echo $quick_link['title']; ?>"><img src="<?php echo $quick_link['icon_url']; ?>" class="h-6 w-6 mr-2"/></a>
								<?php } ?>
                            </div>
						<?php } ?>

                    </div>
                </div>
            </div>
        </div>

        <!-- Click History Report -->
        <div class="mt-5">
            <div class="grid grid-cols-1">
                <div class="mt-2 flex w-full border-b-2 border-gray-100">
                    <div class="w-7/12">
                        <span class="text-xl leading-6 font-medium text-gray-900"><?php _e( 'Clicks History', 'url-shortify' ); ?></span>
						<?php
						if ( ! US()->is_pro() ) {
							?>
                            <span class="pl-5 text-xl text-red-600">[<?php echo sprintf( __( 'Last %d days', 'url-shortify' ), 7 ); ?>]</span> <?php } ?>
                        <p class="mt-1 max-w-2xl text-sm leading-5 text-gray-500 mb-2"><?php echo sprintf( __( '%d Total Clicks', 'url-shortify' ), $total_clicks ); ?></p>
                    </div>
                    <div class="w-5/12">
                        <div class="inline">
							<span class="rounded-md shadow-sm float-right mr-3">
								<button type="button" class="kc-us-primary-button w-full bg-green-500 hover:bg-green-400 text-white" title="<?php echo sprintf( __( 'Last Updated On: %s', 'url-shortify' ), $elapsed_time ); ?>">
									<a href="<?php echo $page_refresh_url; ?>" class="text-white hover:text-white"><?php _e( 'Refresh', 'url-shortify' ); ?></a>
								</button>
							</span>
                        </div>
                    </div>
                </div>
                <div class="bg-white mt-2" id="click-chart">

                </div>
            </div>
        </div>

        <!-- Country & Referrer Info -->
        <div class="mt-6">
            <div class="grid md:grid-cols-2 md:grid-cols-2 sm:grid-cols-1 gap-4">
                <!-- Country Info -->
                <div class="overflow-hidden  rounded-lg">

                    <div class="mb-4">
                        <span class="text-xl leading-6 font-medium text-gray-900"><?php _e( 'Top Locations', 'url-shortify' ); ?></span>
                    </div>

                    <div class="bg-white border-2">
						<?php
						if ( US()->is_pro() ) {
							do_action( 'kc_us_render_country_info', $data );
						} else {
							?>
                            <div class="w-full h-64 p-10 bg-green-50">
                                <div class="">
                                    <div class="mx-auto flex items-center justify-center h-16 w-16 rounded-full bg-green-100">
                                        <svg class="h-12 w-12 text-green-600" fill="none" stroke-linecap="round" stroke-linejoin="round" stroke-width="2" viewBox="0 0 24 24" stroke="currentColor">
                                            <path d="M12 15v2m-6 4h12a2 2 0 002-2v-6a2 2 0 00-2-2H6a2 2 0 00-2 2v6a2 2 0 002 2zm10-10V7a4 4 0 00-8 0v4h8z"></path>
                                        </svg>
                                    </div>
                                    <div class="mt-3 text-center sm:mt-5">
                                        <h3 class="text-lg leading-6 font-medium text-gray-900" id="modal-headline">
											<?php echo sprintf( __( '<a href="%s">Upgrade Now</a>', 'url-shortify' ), US()->get_pricing_url() ); ?>
                                        </h3>
                                        <div class="mt-2">
                                            <p class="text-sm leading-5 text-gray-500">
												<?php _e( 'Get insights about top locations from where people are clicking on your links.', 'url-shortify' ); ?>
                                            </p>
                                        </div>
                                    </div>
                                </div>
                            </div>
						<?php } ?>
                    </div>
                </div>

                <!-- Referrer Info -->
                <div class="overflow-hidden rounded-lg h-px-400">
                    <div class="mb-4">
                        <span class="text-xl leading-6 font-medium text-gray-900"><?php _e( 'Referrers', 'url-shortify' ); ?></span>
                    </div>
                    <div class="bg-white border-2" id="">
						<?php
						if ( US()->is_pro() ) {
							do_action( 'kc_us_render_referrer_info', $data );
						} else {
							?>
                            <div class="w-full h-64 p-10 bg-green-50">
                                <div class="">
                                    <div class="mx-auto flex items-center justify-center h-16 w-16 rounded-full bg-green-100">
                                        <svg class="h-12 w-12 text-green-600" fill="none" stroke-linecap="round" stroke-linejoin="round" stroke-width="2" viewBox="0 0 24 24" stroke="currentColor">
                                            <path d="M12 15v2m-6 4h12a2 2 0 002-2v-6a2 2 0 00-2-2H6a2 2 0 00-2 2v6a2 2 0 002 2zm10-10V7a4 4 0 00-8 0v4h8z"></path>
                                        </svg>
                                    </div>
                                    <div class="mt-3 text-center sm:mt-5">
                                        <h3 class="text-lg leading-6 font-medium text-gray-900" id="modal-headline">
											<?php echo sprintf( __( '<a href="%s">Upgrade Now</a>', 'url-shortify' ), US()->get_pricing_url() ); ?>
                                        </h3>
                                        <div class="mt-2">
                                            <p class="text-sm leading-5 text-gray-500">
												<?php _e( 'Know who are your top referrers.', 'url-shortify' ); ?>
                                            </p>
                                        </div>
                                    </div>
                                </div>
                            </div>
						<?php } ?>
                    </div>
                </div>
            </div>
        </div>

        <!-- Device Info, Browser Info & Platforms Info -->
        <div class="mt-6">
            <div class="grid md:grid-cols-3 sm:grid-cols-1 gap-4">

                <!-- Device Info -->
                <div class="overflow-hidden rounded-lg h-px-400">
                    <div class="mb-4">
                        <span class="text-xl leading-6 font-medium text-gray-900"><?php _e( 'Top Devices', 'url-shortify' ); ?></span>
                    </div>
					<?php
					if ( US()->is_pro() ) {
						do_action( 'kc_us_render_device_info', $data );
					} else {
						?>
                        <div class="w-full h-64 p-10 bg-green-50">
                            <div class="">
                                <div class="mx-auto flex items-center justify-center h-16 w-16 rounded-full bg-green-100">
                                    <svg class="h-12 w-12 text-green-600" fill="none" stroke-linecap="round" stroke-linejoin="round" stroke-width="2" viewBox="0 0 24 24" stroke="currentColor">
                                        <path d="M12 15v2m-6 4h12a2 2 0 002-2v-6a2 2 0 00-2-2H6a2 2 0 00-2 2v6a2 2 0 002 2zm10-10V7a4 4 0 00-8 0v4h8z"></path>
                                    </svg>
                                </div>
                                <div class="mt-3 text-center sm:mt-5">
                                    <h3 class="text-lg leading-6 font-medium text-gray-900" id="modal-headline">
										<?php echo sprintf( __( '<a href="%s">Upgrade Now</a>', 'url-shortify' ), US()->get_pricing_url() ); ?>
                                    </h3>
                                    <div class="mt-2">
                                        <p class="text-sm leading-5 text-gray-500">
											<?php _e( 'Want to know which devices were used to access your links?', 'url-shortify' ); ?>
                                        </p>
                                    </div>
                                </div>
                            </div>
                        </div>
					<?php } ?>
                </div>

                <!-- Browser Info -->
                <div class="overflow-hidden rounded-lg h-px-400">
                    <div class="mb-4">
                        <span class="text-xl leading-6 font-medium text-gray-900"><?php _e( 'Top Browsers', 'url-shortify' ); ?></span>
                    </div>
					<?php
					if ( US()->is_pro() ) {
						do_action( 'kc_us_render_browser_info', $data );
					} else {
						?>
                        <div class="w-full h-64 p-10 bg-green-50">
                            <div class="">
                                <div class="mx-auto flex items-center justify-center h-16 w-16 rounded-full bg-green-100">
                                    <svg class="h-12 w-12 text-green-600" fill="none" stroke-linecap="round" stroke-linejoin="round" stroke-width="2" viewBox="0 0 24 24" stroke="currentColor">
                                        <path d="M12 15v2m-6 4h12a2 2 0 002-2v-6a2 2 0 00-2-2H6a2 2 0 00-2 2v6a2 2 0 002 2zm10-10V7a4 4 0 00-8 0v4h8z"></path>
                                    </svg>
                                </div>
                                <div class="mt-3 text-center sm:mt-5">
                                    <h3 class="text-lg leading-6 font-medium text-gray-900" id="modal-headline">
										<?php echo sprintf( __( '<a href="%s">Upgrade Now</a>', 'url-shortify' ), US()->get_pricing_url() ); ?>
                                    </h3>
                                    <div class="mt-2">
                                        <p class="text-sm leading-5 text-gray-500">
											<?php _e( 'Get information about browsers.', 'url-shortify' ); ?>
                                        </p>
                                    </div>
                                </div>
                            </div>
                        </div>
					<?php } ?>
                </div>


                <!-- OS Info -->
                <div class="overflow-hidden rounded-lg h-px-400">
                    <div class="mb-4">
                        <span class="text-xl leading-6 font-medium text-gray-900"><?php _e( 'Top Platforms', 'url-shortify' ); ?></span>
                    </div>
					<?php
					if ( US()->is_pro() ) {
						do_action( 'kc_us_render_os_info', $data );
					} else {
						?>
                        <div class="w-full h-64 p-10 bg-green-50">
                            <div class="">
                                <div class="mx-auto flex items-center justify-center h-16 w-16 rounded-full bg-green-100">
                                    <svg class="h-12 w-12 text-green-600" fill="none" stroke-linecap="round" stroke-linejoin="round" stroke-width="2" viewBox="0 0 24 24" stroke="currentColor">
                                        <path d="M12 15v2m-6 4h12a2 2 0 002-2v-6a2 2 0 00-2-2H6a2 2 0 00-2 2v6a2 2 0 002 2zm10-10V7a4 4 0 00-8 0v4h8z"></path>
                                    </svg>
                                </div>
                                <div class="mt-3 text-center sm:mt-5">
                                    <h3 class="text-lg leading-6 font-medium text-gray-900" id="modal-headline">
										<?php echo sprintf( __( '<a href="%s">Upgrade Now</a>', 'url-shortify' ), US()->get_pricing_url() ); ?>
                                    </h3>
                                    <div class="mt-2">
                                        <p class="text-sm leading-5 text-gray-500">
											<?php _e( 'Know more about which devices people used to access your links.', 'url-shortify' ); ?>
                                        </p>
                                    </div>
                                </div>
                            </div>
                        </div>
					<?php } ?>
                </div>
            </div>
        </div>

        <!-- Clicks Info -->
        <div class="mt-10 flex w-full">
            <div class="w-8/12">
                <span class="text-xl leading-6 font-medium text-gray-900"><?php _e( 'Clicks Details', 'url-shortify' ); ?></span>
				<?php
				if ( ! US()->is_pro() ) {
					?>
                    <span class="pl-5 text-xl text-red-600">[<?php echo sprintf( __( 'Last %d days', 'url-shortify' ), 7 ); ?>]</span> <?php } ?>
            </div>
			<?php if ( ! US()->is_pro() ) { ?>
                <div class="w-4/12">
                    <div class="flex rounded bg-green-50">
                        <div class="flex-shrink-0">
                            <svg class="h-5 w-5 text-green-400" fill="currentColor" viewBox="0 0 20 20">
                                <path fill-rule="evenodd" d="M10 18a8 8 0 100-16 8 8 0 000 16zm3.707-9.293a1 1 0 00-1.414-1.414L9 10.586 7.707 9.293a1 1 0 00-1.414 1.414l2 2a1 1 0 001.414 0l4-4z" clip-rule="evenodd"/>
                            </svg>
                        </div>
                        <div class="ml-3">
                            <h3 class="text-sm leading-5 font-medium text-green-800">
								<?php echo sprintf( __( '<a href="%s">Past 7 days clicks history is stored. Upgrade to PRO and store full clicks history</a>', 'url-shortify' ), US()->get_pricing_url() ); ?>
                            </h3>
                        </div>
                    </div>
                </div>
			<?php } ?>
        </div>
        <div class="bg-white flex-grow container mx-auto sm:px-4 mt-4 pt-6 pb-8">

            <div>
                <table id="clicks-data" class="display" style="width:100%">
                    <thead>
					<?php $click_history->render_header(); ?>
                    </thead>
                    <tbody>
					<?php
					foreach ( $clicks_data as $click ) {
						$click_history->render_row( $click );
					}
					?>
                    </tbody>
                    <tfoot>
					<?php $click_history->render_footer(); ?>
                    </tfoot>
                </table>
            </div>
        </div>

    </div>

</div>

<script type="text/javascript">

	(function ($) {

		$(document).ready(function () {

			var labels =
				<?php
				if ( ! empty( $labels ) ) {
					echo $labels;
				} else {
					echo "''";
				}
				?>
			;

			var values =
				<?php
				if ( ! empty( $values ) ) {
					echo $values;
				} else {
					echo "''";
				}
				?>
			;

			if (labels != '' && values != '') {
				const data = {
					labels: labels,
					datasets: [
						{
							values: values
						},
					]
				};

				const chart = new frappe.Chart("#click-chart", {
					title: "",
					data: data,
					type: 'axis-mixed',
					colors: ['#5850ec'],
					lineOptions: {
						hideDots: 1,
						regionFill: 1
					},
					height: 250,
					axisOptions: {
						xIsSeries: true
					}
				});
			}


		});

	})(jQuery);

</script>
